SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84

[ROCm/hip commit: e6ded45898]
This commit is contained in:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
committed by GitHub
parent 7925014449
commit 8613cfe299
14 changed files with 47 additions and 47 deletions
@@ -23,6 +23,6 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern "C" __global__ void hello_world(float* a, float* b) {
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
b[tx] = a[tx];
}